@@ -17,7 +17,7 @@
 %                               November 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2001 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -536,6 +536,7 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
   if (xcfdata == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
+  (void) memset(xcfdata,0,(size_t) data_length*sizeof(*xcfdata));
   xcfodata=xcfdata;
   count=ReadBlob(image, (size_t) data_length, xcfdata);
   xcfdatalimit = xcfodata+count-1;
@@ -566,6 +567,8 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
           size-=length;
           if (size < 0)
             goto bogus_rle;
+          if ((length < 1) || (length > data_length))
+            goto bogus_rle;
           if (&xcfdata[length-1] > xcfdatalimit)
             goto bogus_rle;
           while (length-- > 0)
